/****************************************************************
 *								*
 * Copyright (c) 2001-2019 Fidelity National Information	*
 * Services, Inc. and/or its subsidiaries. All rights reserved.	*
 *								*
 *	This source code contains the intellectual property	*
 *	of its copyright holder(s), and is made available	*
 *	under a license.  If you do not know the terms of	*
 *	the license, please stop and do not read further.	*
 *								*
 ****************************************************************/

#ifndef SGNL_INCLUDED
#define SGNL_INCLUDED

void sgnl_gvnulsubsc(char *place);
void sgnl_gvreplerr(void);
void sgnl_gvundef(void);


#endif /* SGNL_INCLUDED */
